/********************************************************************
 *	BizyCorp / Ekwa Internal development Team
 *
 * 	This is reusable manual pagination JS code file. This can be used for any
 * 	DHTMLX grid to implement manual pagination. 
 *
 *  	How to use :- 
 *  
 *  	In order to work with JS manual pagination object you need to do following
 *  	5 steps.
 *
 *		step 1: Edit/verify existing Model class to pass necessary record data to
 *		        controller 
 *	
 * 			1. Add or verify if the following code segment is present inside
 * 			   get_data() function before return $out; statement.
 *
 *			   $out['metadata']=$header;
 *			   $out['total_rows']= $total_num_records;
 *			   $out['result_set'] = $result;
 *			   $out['limit'] = $data['limit'];
 *			   $out['offset'] = $data['offset'];
 *		
 *
 *		step 2: Edit/verify existing Controller class to pass necessary record
 *		        data to view file 
 * 
 * 			1. Add or verify if the following code segment is present inside index()
 * 			   function befor $this->load->view($file,$wrapped_data); statment.
 *
 *			     $wrapped_data['limit'] = $limit;
 *			     $wrapped_data['offset'] = $offset;
 *
 *			
 *		step 3: Edit/verify existing CIGen helper file
 *
 * 			1. Add or verify if following code changes are present in your
 * 			   application's CIGen helper file's converDHTMLXGrid() function. Add
 * 			   following code	
 * 			   
 *         after, 
 *			   $nrows = sizeof($dataset); 
 *			   statement and before, 
 *
 *			   //set header for XML Using DOM to do a clean job
 *   		   $doc = new DOMDocument('1.0', 'UTF-8');
 *   		    	
 *			   // manual pagination related code
 *			   $totrows = $data['dataset']['total_rows'];
 *    		 $nnrows = ($nrows < $nnrows)?$nrows:$nnrows;
 *    		 $limit = $data['dataset']['limit'];
 *			   $offset = $data['dataset']['offset'];
 *			   $tot_recs = $totrows;
 *			   if($limit>0) $tot_pages = ceil($tot_recs/$limit); else $tot_pages = 
 *			    1;
 *
 * 			2. Add or verify following code segment inside if($sr){} condition
 * 			   immediately after $myrows->setAttribute('rec_count',$nrows);
 * 			   statement.
 *
 *     		$myrows->setAttribute('total_rec', $tot_recs);
 *    		$myrows->setAttribute('limit', $limit);
 *     		$myrows->setAttribute('offset', $offset);
 *     		$myrows->setAttribute('tot_pages', $tot_pages);	
 *
 *
 *
 *		step 4: You need to include this file as a JS code include as follows, 
 *				
 *			<script type="text/javascript" src="www.servername/frameworks/
 *			 ekwacommonlib/jslib/pagination.js"></script>
 *				
 *
 *		  If you have done the changes correctly, you should see the xml with new
 *		  attributes in <rows> tag with additional pagination data as follows,
 *
 *		  calling URL:
 *
 *		  http://appdomain.com/appfolder/index.php/controler/index/true/limit/
 *		  offset/some_gridfeed/XML/
 *
 *		  XML output: 
 *
 *		  <rows pos="0" rec_count="11" total_rec="11" limit="20" offset="0" 
 *		  tot_pages="1">
 *
 *			 <row id="194">
 *				<cell style="" fieldName="report_name">
 *					February-2014-Arellano_Leo_February_2014_latest
 *				</cell>
 *			 </row>	
 *			 ...
 *			 ...
 *		  </rows>
 *
 *		step 5: call pagination object inside grid 'onXLE' event as follows. When
 *		        you create pagination object you need to pass 3 parameeters.
 * 
 *			     1 grid object,
 *			     2 pagination div id,
 *			     3 number of records to be shown per page,
 *		
 *			     grid.attachEvent("onXLE", function() {
 *
 *	  			    var obj = new paginationObject(this,"divPagination",20);
 *	  			    obj.preparePaginationElements();
 *		 	
 *	 		     });
 *
 *		IMPORTANT: When you first time initiate the grid make sure you pass same
 *		           record limit as you pass to pagination object
 *		      eg: 
 *			         yourGrid.init();    
 *			         yourGrid.loadXML("<?php echo base_url()?>index.php/controler/
 *			         index/true/20/0/archive_gridfeed/XML/?status_equal=1");
 *	
 *			     here we pass 20 as default record limit 0 as starting offset.
 *
 *  	Author :- Mohamed Roshan (roshan@ekwa.com)
 *  	Creation date  :- 05/05/2014
 *  	Version :- 1.0
 *  	Modified By :- Channa Dewamitta
 *  	Last Modification :- Correced and generalised this header doc  
 *	
 */

function paginationObject(grid,container,userLimit){
		
		var debug = false;
	 	var userLimit = userLimit;
	 	
		var currUrl = null;
		var curr_page_no = 1;	
		var firstUrlPart = null;
		var lastUrlPart = null; 
		var urlPara = null;
		var functionName = null;
		var search = null;
		var urlLimit = null;
		var urlOffset = null;
		var viewName = null;
		var viewType = null;
		var qryString = null;
		var lastOffset = null;
		

		var btnFirst = null;
		var btnPrev = null;
		var btnNext = null;
		var btnLast = null;

		var pageNo = null;
		var selPage = null;
					

	/**
	 * refreshGridPage(sel)
	 *
	 * This function refreshes grid based on selected record paging.
	 * based on page no dropdown menu value this counts new offset and prepare new
	 * url with new offset value
	 * and then gives controll over to loadPages()
	 *
	 */		
	refreshGridPage = function (sel){

			var selValue = sel.value;
			pageNo = selValue;
			var pageOffset  = (parseInt(pageNo) * parseInt(urlLimit));

			if(debug) console.log('refreshGridPage() url parts:-functionName:',functionName,'search:',search,'limit:',urlLimit,'offset:',pageOffset,'viewName:',viewName,'viewType:',viewType,'QrySrting:',qryString);
			
			//prepare new url		
			newUrl = firstUrlPart +  functionName + '/' + search + '/' + urlLimit + '/'+pageOffset+'/' + viewName + '/' + viewType + '/' + qryString;
			if(debug) console.log('refreshGridPage() new URL:-',newUrl);
			
			//pass grid obj to avoide JS error in loadPages() button id
			this.loadPages(newUrl,grid);
			
	};//end of function
	
	

		
	/**
	 * refreshGrid(sel)
	 * 
	 * This function refreshes grid with new recrd limit dropdown value.
	 * based on the record number value this function prepares new url with new
	 * record limit and pass on the controll to loadpages() 
	 *
	 */		
	 refreshGrid = function (sel){

	    	var selValue = sel.value;	 		
	 		if(debug) console.log('sel Value:',selValue);
	 		urlLimit = selValue;	 		

	 		if(debug) console.log('refreshGrid() url parts:-functionName:',functionName,'search:',search,'limit:',urlLimit,'offset:',urlOffset,'viewName:',viewName,'viewType:',viewType,'QrySrting:',qryString);
	 		
	 		//prepare new url		
	 		newUrl = firstUrlPart +  functionName + '/' + search + '/' + urlLimit + '/0/' + viewName + '/' + viewType + '/' + qryString;
	 		if(debug) console.log('refreshGrid() new URL:-',newUrl);
	 		
	 		//pass grid obj to avoide JS error in loadPages() button id
	 		this.loadPages(newUrl,grid);
	 		
 	};//end of function




	/**
	 * loadPages(newUrl,button)
	 * 
	 * This function loads new records xml feed for suplied url.
	 * url shoud consist of new offset,limit to retrive new records xml
	 * On recive of xml feed this then refreses grid with new records 
	 *
	 */
	 loadPages = function(newUrl,button){
	 		
	 		var buttonId = button.id;						
	 		grid.clearAndLoad(newUrl);		
	 		if(debug)console.log('loadPages() :- clicked button id:',buttonId,',new URL:',newUrl);		
	 		
	 };//end of function



	 
	 /**
	 * adjustPageNo()
	 *
	 * This function adjusts page drop down menu to cooporate new record set.
	 * based on global offset,limit values this function ditermin new page value
	 * and changes page dropdown menu value
	 *
	 */	 	
	this.adjustPageNo = function(){

	 		var newPageNo = parseInt(urlOffset) / parseInt(urlLimit);
	 		selPage = document.getElementById('selPages');		
	 		selPage.selectedIndex = newPageNo;
	 		if(debug)console.log('adjustPageNo() :- new page no:',newPageNo);
	 };
	 	
	 	
	 
	 	
	/**
	 * preparePaginationElements(grid)
	 * 
	 * This function prepare pagination footer element based on xml and global url
	 * values and then pass over the controller to pagination footer function
	 *
	 */
    this.preparePaginationElements = function (){
	    		
	 		currUrl = grid.xmlLoader.filePath;
	 		curr_page_no = 1;

	 		//var url = grid.xmlLoader.filePath;
	 		firstUrlPart = this.strstr(currUrl, 'index/',true); // gets only http://localhost:81/MER/index.php/archive/
	 		lastUrlPart = this.strstr(currUrl, 'index/'); // gets last part of the url: 'index/true/5/5/archive_gridfeed/XML/'
	 		urlPara = lastUrlPart.split('/'); // [0] => index [1] => true [2] => 5(limit) [3] => 5 (offset)

	 		functionName = urlPara[0];
	 		search = urlPara[1];
	 		urlLimit = urlPara[2];
	 		urlOffset = urlPara[3];
	 		viewName = urlPara[4];
	 		viewType = urlPara[5];
	 		qryString = urlPara[6];

	 		//if(urlLimit == 0) urlLimit = userlimit;
	 		//if(urlOffset == 0 && urlLimit > userlimit) urlLimit = userlimit; 
	 		
	 		if(debug) console.log('preparePaginationElements(): url parts:-functionName:',functionName,'search:',search,'limit:',urlLimit,'offset:',urlOffset,'viewName:',viewName,'viewType:',viewType,'QrySrting:',qryString);
	 		
	 		Mytotal_rec = grid.xmlLoader.doXPath('//rows/@total_rec')[0].value;			
	 		Mytot_pages = grid.xmlLoader.doXPath('//rows/@tot_pages')[0].value;
	 				
	 		//calculate new offset and drow buttons.
	 		
	 		//prepare first button url		
	 		var firstUrl = firstUrlPart +  functionName + '/' + search + '/' + urlLimit + '/0/' + viewName + '/' + viewType + '/' + qryString;
	 		if(debug) console.log('onXLE Even:firstUrl:-',firstUrl);
	 		
	 		//prepare next button url
	 		var prevOffset = 0 ;		
	 		if(parseInt(urlOffset) > parseInt(urlLimit)){
	 			prevOffset = parseInt(urlOffset) - parseInt(urlLimit);
	 		}		
	 		var prevUrl = firstUrlPart +  functionName + '/' + search + '/' + urlLimit + '/' + prevOffset + '/'  + viewName + '/' + viewType + '/' + qryString;
	 		if(debug) console.log('onXLE Even:prevUrl:-',prevUrl);
	 				
	 		//calculate next offset
	 		
	 		nextOffset = parseInt(urlOffset) + parseInt(urlLimit);		
	 		var nextUrl = firstUrlPart +  functionName + '/' + search + '/' + urlLimit + '/' + nextOffset + '/'  + viewName + '/' + viewType + '/' + qryString;
	 		if(debug) console.log('onXLE Even:nextUrl:-',nextUrl);
	 		
	 		//prepare last button url
	 		lastOffset = (parseInt(Mytot_pages) * parseInt(urlLimit) ) - parseInt(urlLimit);	
	 		var lastUrl = firstUrlPart +  functionName + '/' + search + '/' + urlLimit + '/' + lastOffset + '/'  + viewName + '/' + viewType + '/' + qryString;
	 		if(debug) console.log('onXLE Even:lastUrl:-',lastUrl);

	 		//current page no
	 		curr_page_no = (parseInt(urlOffset) / parseInt(urlLimit)) + 1;

	 		//now pring pagination buttons
	 		this.showPaginationFooter(firstUrl,prevUrl,nextUrl,lastUrl,urlLimit,Mytot_pages,Mytotal_rec,curr_page_no,container);		
	 		
	 };//end of function




	 /**
	  * showPaginatinFooter(firstUrl,prevUrl,nextUrl,lastUrl,limit,tot_pages,tot_recs,curr_page_no,pagin_div_id)
	  *
	  * This function prints pagination block at a given div id.
	  *
	  * firstUrl,prevUrl,nextUrl,lastUrl (string) - url of the buttons. Url should embeded with calculated offset and limit values
	  * limit int - record limit
	  * tot_recs int - total record count
	  * curr_page_no int - current record page no
	  * pagin_div_id  string - pagination div id
	  *  
	  */
	 this.showPaginationFooter = function (firstUrl,prevUrl,nextUrl,lastUrl,limit,tot_pages,tot_recs,curr_page_no,pagin_div_id){

			var divPagination = document.getElementById(pagin_div_id);		
			var lastRecords = (parseInt(urlLimit) + parseInt(urlOffset));
			if(lastRecords > tot_recs){lastRecords = tot_recs;}
			
			var paging = 
				'<div id="divPageButtons" class="dhx_toolbar_base_dhx_skyblue">'+
				'<input type="button" id="btnFirst" onclick="loadPages(\''+ firstUrl +'\',this)" value="|<" style="height:23;width:23" >' +  
				'<input type="button" id="btnPrev" onclick="loadPages(\''+ prevUrl +'\',this)" value="<" style="height:23;width:23" >'+
				'<input type="button" id="btnNext"  onclick="loadPages(\''+ nextUrl +'\',this)" value=">" style="height:23;width:23" >'+
				'<input type="button" id="btnLast" onclick="loadPages(\''+ lastUrl +'\',this)" value=">|" style="height:23;width:23" >'+
				'<select name="selPages" id="selPages" onchange="refreshGridPage(this)">';
				
				if(tot_recs>0){
					for(var n = 0;n<tot_pages;n++){
						if(pageNo == n){
							paging +='<option value="'+n+'" selected="selected">Page '+(parseInt(n) + 1)+'</option>';
						}else{
							paging +='<option value="'+n+'">Page '+(parseInt(n) + 1)+'</option>';
						}	
					}
	 			}else{ 	
	 				paging +='<option value="0">Page 1 </option>'; 
	 			}
				paging +='</select>'+
				'<select name="selLimit" id="selLimit" onchange="refreshGrid(this)">';

				var idx = 0;
				idx = userLimit;
				if(Mytotal_rec != 0){
				while(idx <= Mytotal_rec){
					if(urlLimit == idx){
						paging += '<option value="'+idx+'" selected="selected">'+ idx+' rows per page</option>';
					}else{
						paging += '<option value="'+idx+'" >'+ idx+' rows per page</option>';
					}	
					idx = parseInt(idx) + parseInt(userLimit);
				}
				}else{
					paging += '<option value="'+userLimit+'" >'+ userLimit+' rows per page</option>';
				}
				
				if(Mytotal_rec < userLimit){
					paging += '<option value="'+userLimit+'" >'+ userLimit+' rows per page</option>';
				}
				paging += '</select>';
				
				if(Mytotal_rec == 0){
					paging += ' No records found ';	
				}else{
					paging +=' ' + (parseInt(urlOffset) + 1)+			
					' to '+ lastRecords +
					' of '+ tot_recs +
					' records ';
				}
				paging +='</div>';
				
			divPagination.innerHTML = paging;

			//toggle the pagination buttn	
			this.toggleButtons();

			//adjust paging number on page dropdown menu
			this.adjustPageNo();
				
	};//end of function


		 
	/**
	 * toggleButtons()
	 *
	 * This function makes pagination bottons to be toggled between enable and disable.
	 * based on globle url offset values,this function identified first and last set of records
	 *
	 */		
	 this.toggleButtons = function(){

			btnFirst = document.getElementById('btnFirst');
			btnPrev = document.getElementById('btnPrev');
			btnNext = document.getElementById('btnNext');
			btnLast = document.getElementById('btnLast');
					
			if(debug) console.log('toggleButtons():-urlOffset:',urlOffset,' lastOffset:',lastOffset);
			
			if(urlOffset == 0){
				
				btnFirst.disabled = true;
				btnPrev.disabled = true;
				btnNext.disabled = false;
				btnLast.disabled = false;
				
			}else if(urlOffset == lastOffset){
				
				btnFirst.disabled = false;
				btnPrev.disabled = false;
				btnNext.disabled = true;
				btnLast.disabled = true;
				
			}
			if(urlOffset == 0 && lastOffset == 0){
				
				btnFirst.disabled = true;
				btnPrev.disabled = true;
				btnNext.disabled = true;
				btnLast.disabled = true;
			}
			if(Mytotal_rec == 0){
				
				btnFirst.disabled = true;
				btnPrev.disabled = true;
				btnNext.disabled = true;
				btnLast.disabled = true;
			}
					
	};//end of function
			 
		 
		/**
		 * strstr(haystack, needle, bool)
		 * 
		 * This function is similer to PHP strstr(). This function utilizes few core
		 * JS functions to perform the task visit http://phpjs.org/functions/strstr/
		 * for more information
		 *  
		 *	original by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
		 *	bugfixed by: Onno Marsman
		 *	improved by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
		 *	 example 1: strstr('Kevin van Zonneveld', 'van');
		 *	 returns 1: 'van Zonneveld'
		 *	 example 2: strstr('Kevin van Zonneveld', 'van', true);
		 *	 returns 2: 'Kevin '
		 *	 example 3: strstr('name@example.com', '@');
		 *	 returns 3: '@example.com'
		 *	 example 4: strstr('name@example.com', '@', true);
		 *	 returns 4: 'name'
		 *	 
		 */
	 	this.strstr = function (haystack, needle, bool) {
			  
			  var pos = 0;
			  haystack += '';
			  pos = haystack.indexOf(needle);
			  if (pos == -1) {
			    return false;
			  } else {
			    if (bool) {
			      return haystack.substr(0, pos);
			    } else {
			      return haystack.slice(pos);
			    }
			  }
			  
	     }//end of function		 



}//end of pagination object
	 	 
