<?php
/**
 * This class creates a simple object to access data fields in any of our
 * XML feeds coming from INDEX methods.
 *
 *
 * It creates a extended simpleXMLElement object with all the fields on the
 * root node. so you can just use the standard object notation like
 * obj->field_name to access the field values.
 * The getRecords method returns all the records as an iteratable object 
 * indexed with the row id.
 *
 * @package ECAACS\common
 * @author Channa Dewamitta
 * @license Ekwa Internal Systems Development
 * @version 1.0
 * @usage       <pre>To use this class simply include this in the PHP script
 *              as follows
 *              <code>require_once('/path_to_class_file/class.ekwa_xml_feed.php'); </code>
 *              Then get the URL contents to a var as follows
 *              <code>$xml = @file_get_contents($xml_feed_url);</code>
 *              Then convert the feed to simple XML object as follows
 *              <code>$xmlData = simplexml_load_string($xml,"ekwa_xml_feed");</code></pre>
 *
 *
 */
Class ekwa_xml_feed extends SimpleXMLElement
{
	/**
	 * The main method that select the appropriate record from the records set
	 * and create the public properties as per the XML feed
	 * 
	 *
	 * @package ECAACS\common\ekwa_xml_feed
	 * @method init($v,[TRUE|FALSE]) selects the row with the given ID
	 * @param mix $v ithe row ID of the XML feed to be selected
	 * @param bool $iterate - Allows the property traversing for the selected row
	 * 						by removing the original row object and leaving
	 * 						only the selected row's data.
	 * 						NOTE:- Once this
	 * 						is done if you need data of any other row you
	 * 						need to recreate the object.
	 */
	public	function init($v, $iterate = false)
	{
		$prop2bunset = array();
		$fields = $this->xpath("//row[@id=$v]/cell");
		if ($fields){
			foreach($fields as $field){
				$this->{(string) $field['fieldName']} = (string) $field;
			}
			if ($iterate) unset($this->row);
		}else{ //remove any existing properties
			foreach($this as $propname => $propval){
				//echo "<pre>",var_dump($propname)."</pre><br/>";
				if ($propname != "row") $prop2bunset[]=$propname;
			}
			foreach ($prop2bunset as $prop){
				unset($this->$prop);
			}
		}
	}
	
	/**
	 * Methosd retrieves all data records as a standard data object with the
	 * row 'id' as the key if no params are specified.
	 *
	 *
	 *The method is at present imlementation does not accept any params and just
	 *returns all the data records as a standard data object. The usage is as follows;
	 *
	 *$obj = xmlfeed->getResords() and the $obje can be used as follows;
	 *$obj->id->field_name
	 *
	 * @package ECAACS\common\ekwa_xml_feed
	 * @method init($v,[TRUE|FALSE]) selects the row with the given ID
	 * @param mix $v ithe row ID of the XML feed to be selected
	 * @param bool $iterate - Allows the property traversing for the selected row
	 * 						by removing the original row object and leaving
	 * 						only the selected row's data.
	 * 						NOTE:- This method does not create properties rather
	 * 							retuns astandard object with properties and 
	 * 							indexed with row id value. 
	 * @return StdClass obect with the xml feed's data fields as properties
	 * @todo Implement the filter param functionality
	 */
	public function getRecords($filterField=FALSE,$value=FALSE)
	{
		if(($filterField && trim($filterField) =='') && ($value && $value =='')) return FALSE;
		else {
			//$records = array();
			$records = new StdClass;
			$rows = $this->row;
			foreach($rows as $row){
				$id = (string) $row['id'];
				$records->{$id} = new StdClass;
				foreach($row as $key => $val)
				{
					$records->{$id}->{(string) $val['fieldName']} = (string) $val;
				}
			}
		}
		return $records;
	}
}// end class ekwa_xml_feed
?>
